@@ -75,12 +75,11 @@ Rcpp.package.skeleton <- function(
 		) 
 		x <- cbind( read.dcf( DESCRIPTION ), 
 			"Depends" = paste( depends, collapse = ", ") , 
-			"LinkingTo" = "Rcpp", 
-			"SystemRequirements" = "GNU make" )
+			"LinkingTo" = "Rcpp"
+		)
 		write.dcf( x, file = DESCRIPTION )
 		message( " >> added Depends: Rcpp" )
 		message( " >> added LinkingTo: Rcpp" )
-		message( " >> added SystemRequirements: GNU make" )
 	}
 	
 	# if there is a NAMESPACE, add a useDynLib
@@ -95,7 +94,7 @@ Rcpp.package.skeleton <- function(
 		}
 		
 		if(isTRUE(module)){
-			writeLines( 'importClassesFrom( Rcpp, "C++Object", "C++Class", "Module" )', ns )
+			writeLines( 'import( Rcpp )', ns )
 		}
 		close( ns )
 	}
