@@ -262,7 +262,9 @@ private:
 
     void preserve(){ if( m_sexp != R_NilValue ) R_PreserveObject(m_sexp) ; } 
     void release() { if( m_sexp != R_NilValue ) R_ReleaseObject(m_sexp) ; } 
-    virtual void update() {} ;
+    virtual void update() {
+        RCPP_DEBUG_1( "RObject::update(SEXP = <%p> )", m_sexp ) ; 
+    } ;
     
 };
 
